Changelog — django-statici18n 0.3.1 documentation

### Navigation

- index
- modules |
- previous |
- django-statici18n 0.3.1 documentation »

# Changelog

## v0.4.0 (2012 Apr 04)

- Added statici18n template tag.

## v0.3.1 (2012 Apr 03)

- Added license
- Fixed installation error due to missing manifests file.

## v0.3.0 (2012 Apr 03)

- Added Sphinx documentation.
- Added many settings managed with django-appconf.

## v0.2.0 (2012 Apr 02)

Warning

The following chnages are backward-incompatible with the previous release.

- Renamed collecti18n command to compilejsi18n.
- Now use current static directory instead of `STATIC_ROOT` for sane defaults.

## v0.1.0 (2012 Apr 02)

- Initial commit.

### Navigation

- index
- modules |
- previous |
- django-statici18n 0.3.1 documentation »